Ext.namespace('dSS', 'dSS.system');

dSS.system.logfiles = Ext.extend(Ext.Panel, {
    initComponent: function() {
        Ext.apply(this, {
            layout: 'table',
            title: dSS._("Logfiles"),
            defaults: {
                border: false
            },
            layoutConfig: {
                columns: 2,
                tableAttrs: {
                    width: '100%'
                }
            },
            items: [
            {
                colspan: 2,
                html: '<h2>LOGFILES</h2>'
            },
            {
                width: '70%',
                html: '<h2>This is a placeholder</h2><p>Sample text.<br/><br/><br/></p>'
            },
            {
                html: '<p class="x-green-button-link"><a href="images/ds_logo.gif">sample link</a></p>'
            },
            {
                colspan: 2,
                html: '<h2>CONFIGURATION FILES</h2>'
            },
            {
                html: '<h2>Current system configuration</h2><p>Download current system configuration file.<br/> Use: "Right Click > Save Target As..." to download the file. </p>'
            },
            {
                html: '<p class="x-green-button-link"><a href="/download/apartment.xml" target=":_blank">apartment.xml</a></p>'
            }]
        });

        dSS.system.logfiles.superclass.initComponent.apply(this, arguments);
    }
});

Ext.reg('systemlogfiles', dSS.system.logfiles);

Ext.namespace('dSS', 'dSS.system');

dSS.system.jsLogFilesPanel = Ext.extend(Ext.grid.GridPanel, {
    initComponent: function() {
        this.logFileRecord = Ext.data.Record.create([
        {
            name: "logfile",
            mapping: "name"
        },
        {
            name: "download",
            mapping: "download"
        }]);

        this.logFileStore = new Ext.data.ArrayStore({
            storeId: "logFileStore",
            fields: this.logFileRecord
        });

        Ext.apply(this, {
            columns: [
            {
                header: dSS._("Log file"),
                sortable: true,
                dataIndex: "name",
                id: "logfile"
            },
            {
                header: dSS._("Download"),
                sortable: true,
                dataIndex: "download",
                width: 200
            }],
            store: this.logFileStore,
            stripeRows: true,
            autoScroll: true,
            autoExpandColumn: "logfile",
            layout: "fit",
            selModel: new Ext.grid.RowSelectionModel({
                singleSelect: true
            }),
            viewConfig: {
                autoFill: true
            }
        });

        dSS.system.jsLogFilesPanel.superclass.initComponent.apply(this, arguments);

        this.on("afterrender", function(component) {
            this.fillStore();
        },
        this);

        this.on("activate", function(component) {
            this.fillStore();
            var sel = this.getSelectionModel();
            if (sel.hasSelection()) {
                var record = sel.getSelected();
                this.findParentByType("dsssystemjslogfiles").loadLog(record.get("name"));
            }
        },
        this);

        this.on("cellclick", function(grid, rowIndex, columnIndex, e) {
            var record = grid.getStore().getAt(rowIndex);
            this.findParentByType("dsssystemjslogfiles").loadLog(record.get("name"));
        },
        this);
    },

    fillStore: function() {
        Ext.Ajax.request({
            url: "/json/property/getChildren",
            method: "GET",
            scope: this,
            params: {
                path: "/system/js/logfiles"
            },
            success: function(result, request) {
                try {
                    var jsonData = Ext.util.JSON.decode(result.responseText);
                    if (jsonData.ok) {
                        for (i = 0; i < jsonData.result.length; i++) {
                            var link = "<span class=\"x-green-button-link\">" + "<a target=\"_blank\" title=\"" + dSS._("Right click and select Save Link As to " + "download the log file") + "\" href=\"/download/" + jsonData.result[i].name + "\">" + jsonData.result[i].name + "</a></span>";
                            jsonData.result[i].download = link;
                            var r = new this.logFileRecord(
                            jsonData.result[i]);

                            if (this.logFileStore.findExact("name", r.get("name")) === - 1) {
                                this.logFileStore.add([r]);
                            }
                        }
                    } else {
                        Ext.MessageBox.alert(dSS._("Error"), dSS._("Could not get properties from dSS"));
                    }
                } catch(err) {
                    Ext.MessageBox.alert(dSS._("Error"), dSS._("Could not send getChildren command to dSS") + ": " + err);
                }
            },
            failure: function(result, request) {
                Ext.MessageBox.alert(dSS._("Error"), dSS._("Could not send getChildren command to dSS"));
            }
        });
    }
});

Ext.reg('dssjslogfilespanel', dSS.system.jsLogFilesPanel);

Ext.namespace('dSS', 'dSS.system', 'dSS.grid');

dSS.system.jsLogFiles = Ext.extend(Ext.Panel, {
    initComponent: function() {
        this.textPanel = new Ext.Panel({
            region: "center",
            autoScroll: true,
            bodyCfg: {
                tag: "pre"
            }
        });

        this.heightConfigured = false;

        Ext.apply(this, {
            layout: 'border',
            items: [
            {
                xtype: 'dssjslogfilespanel',
                ref: 'jsLogFilesPanel',
                region: 'north',
                split: true
            },
            this.textPanel]
        });

        dSS.system.jsLogFiles.superclass.initComponent.apply(this, arguments);

        this.on("activate", function(component) {
            this.jsLogFilesPanel.fireEvent("activate");

            if (this.heightConfigured === false) {
                this.heightConfigured = true;
                this.jsLogFilesPanel.setHeight(this.getInnerHeight() / 3);
            }
        },
        this);
    },

    loadLog: function(logname) {
        this.textPanel.load({
            url: "/download/" + logname,
            nocache: true,
            scope: this,
            callback: function() {
                this.textPanel.body.dom.scrollTop = this.textPanel.body.dom.scrollHeight;
            }
        });
    }
});

Ext.reg('dsssystemjslogfiles', dSS.system.jsLogFiles);


Ext.namespace('dSS');

dSS.SystemPanel = Ext.extend(Ext.Panel, {
    initComponent: function() {

        var TabRecord = Ext.data.Record.create([
        {
            name: "title"
        }]);

        var tabStore = new Ext.data.Store({},
        TabRecord);

        var contentPanel = {
            ref: 'contentPanel',
            region: 'center',
            layout: 'card',
            hideBorders: true,
            border: true,
            activeItem: 0,
            items: [
            {
                title: dSS._("Property Tree"),
                xtype: 'dsssystempropertytree',
                ref: 'systemPropertyTree'
            },
            {
                title: dSS._("Access authorization"),
                xtype: 'dsstokenauthpanel'
            },
            {
                title: dSS._("Logfiles"),
                xtype: 'systemlogfiles',
                ref: 'systemlogfiles'
            },
            {
                title: dSS._("JS Plugin Logs"),
                xtype: "dsssystemjslogfiles",
                ref: "systemjslogfiles"
            }]
        };

        this.listView = new Ext.list.ListView({
            ref: 'listView',
            store: tabStore,
            singleSelect: true,
            region: 'west',
            hideHeaders: true,
            columns: [
            {
                header: 'name',
                dataIndex: 'title'
            }]
        });

        var listHolder = new Ext.Panel({
            title: "System",
            region: 'west',
            layout: 'fit',
            split: true,
            width: 225,
            minSize: 175,
            maxSize: 400,
            items: [this.listView]
        });

        Ext.apply(this, {
            layout: 'border',
            border: false,
            bodyBorder: false,
            items: [listHolder, contentPanel]
        });

        dSS.SystemPanel.superclass.initComponent.apply(this, arguments);

        this.on('activate', function(component) {
            if (this.initializedTabs) {
                this.contentPanel.layout.activeItem.fireEvent("activate", this.contentPanel.layout.activeItem);
                return;
            }
            this.contentPanel.items.each(function(item) {
                var tab = new TabRecord({
                    title: item.title
                });
                tabStore.add([tab]);
            },
            this);
            this.listView.select(0, false, true);
            this.listView.on('activate', function() {
            },
            this);
            this.listView.on('selectionchange', function(listView, selections) {
                this.contentPanel.layout.setActiveItem(selections[0].viewIndex);
                this.contentPanel.layout.activeItem.fireEvent("activate", this.contentPanel.layout.activeItem);
            },
            this);
            this.initializedTabs = true;
        },
        this);
    }
});

Ext.reg('dsssystempanel', dSS.SystemPanel);

Ext.namespace('dSS', 'dSS.time');

dSS.time.dateprint = function(date, month, year, hour, minute) {
    switch (month) {
    case 0:
        month = "Jan";
        break;
    case 1:
        month = "Feb";
        break;
    case 2:
        month = "Mar";
        break;
    case 3:
        month = "Apr";
        break;
    case 4:
        month = "May";
        break;
    case 5:
        month = "Jun";
        break;
    case 6:
        month = "Jul";
        break;
    case 7:
        month = "Aug";
        break;
    case 8:
        month = "Sep";
        break;
    case 9:
        month = "Oct";
        break;
    case 10:
        month = "Nov";
        break;
    case 11:
        month = "Dec";
        break;
    default:
        month = "";
        break;
    }

    if (hour < 10) {
        hour = ('0' + hour);
    }

    if (minute < 10) {
        minute = ('0' + minute);
    }

    return month + ' ' + date + ' ' + hour + ':' + minute + ', ' + year;
};

dSS.time.update = function() {
    var t = new Date(Date.now() - dSS.config.dSSTimeDiff);
    Ext.get('dssTime').update(dSS.time.dateprint(t.getDate(), t.getMonth(), t.getFullYear(), t.getHours(), t.getMinutes()
    ));
    dSS.time.update.defer(1000);
};


Ext.namespace("dSS", "dSS.config");

dSS.initUI = function() {
	dSS.config.dSSTimeDiff = 0;

    Ext.QuickTips.init();

    Ext.apply(Ext.QuickTips.getQuickTip(), { maxWidth: 500 });

    var params = Ext.urlDecode(window.location.search.substring(1));

    var active = 0;

    var tabs = [
        {
            title: dSS._("Zone", "n% Zones", 2),
            xtype: 'dsszonebrowser',
            ref: 'zoneBrowser'
        },
        {
            title: dSS._("Scene", 2),
            xtype: 'dssscenespanel',
            ref: 'scenesPanel'
        },
        {
            title: dSS._("Meters"),
            xtype: 'dsmoverviewpanel',
            ref: 'dSMOverviewPanel'
        },
        {
            title: dSS._("System Properties"),
            xtype: 'dsssystempanel',
            ref: 'systemPanel'
        }
    ];

    var viewport = new Ext.Viewport({
        layout: 'border',
        items: [
        {
            xtype: 'box',
            region: 'north',
            height: 80,
            autoEl: {
                tag: 'div',
                html: '<a href="http://digitalstrom.org/" alt="' + dSS._("visit digitalSTROM.org") + '"><img id="logo" src="images/ds_logo.gif" alt="dS-Logo"></a>' + '<h1><a href="http://digitalstrom.org/" alt="visit digitalSTROM.org">' + dSS._("digitalSTROM Setup") + '</a></h1>' + '<p><span id= \'dssVersion\'>-</span>, <span id=\'dssTime\'>-</span></p>'
            }
        },
        {
            region: 'center',
            xtype: 'tabpanel',
            activeTab: active,
            items: tabs
        }]
    });

    Ext.Ajax.request({
        url: "/json/system/version",
        disableCaching: true,
        success: function(response, options) {
            try {
                var data = Ext.decode(response.responseText);
                if (data.ok === false) {
                    throw new Ext.Error(dSS._("Could not get dSS version"), data.error);
                }
                Ext.get("dssVersion").update(data.result.version);

            } catch(error) {}
        },
        failure: function(response, options) {}
    });

    Ext.Ajax.request({
        url: "/json/system/time",
        disableCaching: true,
        scope: this,
        success: function(response, options) {
            try {
                var data = Ext.decode(response.responseText);
                if (data.ok === false) {
                    throw new Ext.Error(dSS._("Could not get dSS time"), data.error);
                }
                dSS.config.dSSTimeDiff = (Date.now() - (parseInt(data.result.time, 10) * 1000));
                dSS.time.update();

            } catch(error) {}
        },
        failure: function(response, options) {}
    });

    Ext.Ajax.request({
        url: "/json/property/getChildren",
        params: {
            path: "/system/js/settings"
        },
        scope: this,
        method: "GET",
        disableCaching: true,
        success: function(response, options) {
            try {
                var jsonData = Ext.util.JSON.decode(response.responseText);
                if (jsonData.ok) {
                    for (i = 0; i < jsonData.result.length; i++) {
                        /*
                            dSS.config.settings[jsonData.result[i].name] = jsonData.result[i];
                     */
                        getLogFileProperties(jsonData.result[i]);
                    }
                }
            } catch(err) {}
        },
        failure: function(response, options) {
            Ext.MessageBox.alert(dSS._("Error"), dSS._("Could send getChildren command to dSS"));
        }
    });

    function getLogFileProperties(res) {
        Ext.Ajax.request({
            url: "/json/property/getString",
            params: {
                path: "/system/js/settings/" + res.name + "/logfile"
            },
            scope: this,
            method: "GET",
            disableCaching: true,
            success: function(response, options) {
                try {
                    var jsonData = Ext.util.JSON.decode(response.responseText);
                    if (jsonData.ok) {
                        dSS.config.settings[res.name] = {};
                        dSS.config.settings[res.name].logfile = jsonData.result.value;
                    }
                } catch(err) {}
            },
            failure: function(response, options) {
                Ext.MessageBox.alert(dSS._("Error"), dSS._("Could send getChildren command to dSS"));
            }
        });
    }
};

dSS.mainLogin = function()
{

    if (Ext.isIE6 === true) {
        Ext.Msg.alert(dSS._("Error"),
                      dSS._("Internet Explorer 6 is not supported, please " +
                            "upgrade your webbrowser"));
        return;
    }

    Ext.Ajax.request({
        url: '/json/system/login',
        params: {
            user: 'dssadmin',
            password: 'dssadmin'
        },
        scope: this,
        method: "GET",
        disableCaching: true,
        success: function(response, options) {
            try {
                var jsonData = Ext.util.JSON.decode(response.responseText);
                if (jsonData.ok) {
                    dSS.initUI();
                } else {
                    Ext.Msg.alert(dSS._("Error"),
                                  dSS._("Could not log in") + ': ' +
                                  jsonData.message);
                }
            } catch(err) {
                Ext.Msg.alert(dSS._("Error"),
                              dSS._("Could not log in") + ': ' + err);

            }
        },
        failure: function(response, options) {
            Ext.Msg.alert(dSS._("Error"),
                          dSS._("Could not send login command to dSS"));
        }
    });
};

Ext.onReady(function() {
    Ext.get('start').remove();

    Ext.Ajax.request({
        url: dSS.config.langPath,
        scope: this,
        method: "GET",
        disableCaching: true,
        success: function(response, options) {
            try {
                var data = Ext.util.JSON.decode(response.responseText);

                var params = {
                                'domain' : 'dss-installer',
                                'locale_data' : { 'dss-installer' : data }
                             };
                dSS.gt = new Gettext(params);
                dSS.mainLogin();
            } catch(err) {
                Ext.Msg.alert(dSS._("Error"),
                              dSS._("Could not load language strings") + ': ' +
                              err);
                dSS.mainLogin();

            }
        },
        failure: function(response, options) {
            Ext.Msg.alert(dSS._("Error"),
                          dSS._("Could not load language strings"));
            dSS.mainLogin();
        }
    });
});

